@@ -26,6 +26,62 @@ class CfwClient(AbstractClient):
     _service = 'cfw'
 
 
+    def AddAcRule(self, request):
+        """添加互联网边界规则
+
+        :param request: Request instance for AddAcRule.
+        :type request: :class:`tencentcloud.cfw.v20190904.models.AddAcRuleRequest`
+        :rtype: :class:`tencentcloud.cfw.v20190904.models.AddAcRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("AddAcRule", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AddAcRuleResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def AddEnterpriseSecurityGroupRules(self, request):
+        """创建新企业安全组规则
+
+        :param request: Request instance for AddEnterpriseSecurityGroupRules.
+        :type request: :class:`tencentcloud.cfw.v20190904.models.AddEnterpriseSecurityGroupRulesRequest`
+        :rtype: :class:`tencentcloud.cfw.v20190904.models.AddEnterpriseSecurityGroupRulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("AddEnterpriseSecurityGroupRules", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.AddEnterpriseSecurityGroupRulesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateAcRules(self, request):
         """创建规则
 
@@ -138,6 +194,34 @@ class CfwClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateNatFwInstanceWithDomain(self, request):
+        """创建防火墙实例和接入域名
+
+        :param request: Request instance for CreateNatFwInstanceWithDomain.
+        :type request: :class:`tencentcloud.cfw.v20190904.models.CreateNatFwInstanceWithDomainRequest`
+        :rtype: :class:`tencentcloud.cfw.v20190904.models.CreateNatFwInstanceWithDomainResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateNatFwInstanceWithDomain", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateNatFwInstanceWithDomainResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateSecurityGroupApiRules(self, request):
         """创建安全组API规则
 
@@ -530,6 +614,34 @@ class CfwClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeEnterpriseSecurityGroupRule(self, request):
+        """查询新企业安全组规则
+
+        :param request: Request instance for DescribeEnterpriseSecurityGroupRule.
+        :type request: :class:`tencentcloud.cfw.v20190904.models.DescribeEnterpriseSecurityGroupRuleRequest`
+        :rtype: :class:`tencentcloud.cfw.v20190904.models.DescribeEnterpriseSecurityGroupRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeEnterpriseSecurityGroupRule", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeEnterpriseSecurityGroupRuleResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeGuideScanInfo(self, request):
         """DescribeGuideScanInfo新手引导扫描接口信息
 
@@ -1682,6 +1794,62 @@ class CfwClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RemoveAcRule(self, request):
+        """删除互联网边界规则
+
+        :param request: Request instance for RemoveAcRule.
+        :type request: :class:`tencentcloud.cfw.v20190904.models.RemoveAcRuleRequest`
+        :rtype: :class:`tencentcloud.cfw.v20190904.models.RemoveAcRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RemoveAcRule", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RemoveAcRuleResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def RemoveEnterpriseSecurityGroupRule(self, request):
+        """删除新企业安全组规则
+
+        :param request: Request instance for RemoveEnterpriseSecurityGroupRule.
+        :type request: :class:`tencentcloud.cfw.v20190904.models.RemoveEnterpriseSecurityGroupRuleRequest`
+        :rtype: :class:`tencentcloud.cfw.v20190904.models.RemoveEnterpriseSecurityGroupRuleResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RemoveEnterpriseSecurityGroupRule", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RemoveEnterpriseSecurityGroupRuleResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RunSyncAsset(self, request):
         """同步资产-互联网&VPC
 
